Two-stage example Small example dataset for demonstrating matching, censoring imputation, and treatment-rule learning functions in DRMLSurv.
DATASET.RdTwo-stage example Small example dataset for demonstrating matching, censoring imputation, and treatment-rule learning functions in DRMLSurv.
Usage
data(DATASET)